Advanced Fitting Tutorial
==========================

This tutorial covers MCMC methods and parameter constraints.

.. note::

   This tutorial is also available as a Jupyter notebook: :download:`03_advanced_fitting.ipynb <../../notebooks/03_advanced_fitting.ipynb>`

.. include:: ../../notebooks/03_advanced_fitting.ipynb
   :parser: myst_nb.docutils_
